{ This file was automatically created by Lazarus. Do not edit!
  This source is only used to compile and install the package.
 }

unit lclfpreport;

{$warn 5023 off : no warning about unused units}
interface

uses
  cfgfpreportimageexport, cfgfpreportpdfexport, fpreportformexport, 
  fpreportlclexport, fpreportprinterexport, fpreportpreview, dlginputcombo, 
  cfgfpreporthtmlexport, lclfpreportbuild, LazarusPackageIntf;

implementation

procedure Register;
begin
end;

initialization
  RegisterPackage('lclfpreport', @Register);
end.
